package org.framework.lazy.cloud.network.heartbeat.client.config;


import org.framework.lazy.cloud.network.heartbeat.client.netty.advanced.*;
import org.framework.lazy.cloud.network.heartbeat.client.netty.event.ClientChangeEvent;
import org.framework.lazy.cloud.network.heartbeat.common.advanced.HandleChannelTypeAdvanced;
import org.springframework.beans.factory.config.BeanDefinition;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Role;

import java.util.List;

@Role(BeanDefinition.ROLE_INFRASTRUCTURE)
@ConditionalOnProperty(prefix = NettyClientProperties.PREFIX, name = "enabled", havingValue = "true", matchIfMissing = true)
public class HeartbeatClientConfiguration {

    /**
     * 服务端 处理客户端心跳
     *
     * @return ClientTcpHandleChannelHeartbeatTypeAdvanced
     */
    @Bean
    public ClientTcpHandleChannelHeartbeatTypeAdvanced clientChannelHeartbeatTypeAdvanced() {
        return new ClientTcpHandleChannelHeartbeatTypeAdvanced();
    }

    /**
     * 处理 客户端代理的真实端口自动读写
     *
     * @return ClientHandleTcpDistributeSingleClientRealAutoReadConnectTypeAdvanced
     */
    @Bean
    public ClientHandleTcpDistributeSingleClientRealAutoReadConnectTypeAdvanced handleDistributeSingleClientRealAutoReadConnectTypeAdvanced() {
        return new ClientHandleTcpDistributeSingleClientRealAutoReadConnectTypeAdvanced();
    }

    /**
     * 处理 接收服务端发送过来的聊天信息
     *
     * @return ClientHandleTcpDistributeSingleClientMessageTypeAdvanced
     */
    @Bean
    public ClientHandleTcpDistributeSingleClientMessageTypeAdvanced handleDistributeSingleClientMessageTypeAdvanced() {
        return new ClientHandleTcpDistributeSingleClientMessageTypeAdvanced();
    }
    /**
     * 处理 客户端渗透服务端数据传输通道连接成功
     *
     * @return ClientHandleTcpDistributeClientTransferServerPermeateChannelConnectionSuccessfulTypeAdvanced
     */
    @Bean
    public ClientHandleTcpDistributeClientTransferServerPermeateChannelConnectionSuccessfulTypeAdvanced clientHandleDistributeClientTransferServerPermeateChannelConnectionSuccessfulTypeAdvanced() {
        return new ClientHandleTcpDistributeClientTransferServerPermeateChannelConnectionSuccessfulTypeAdvanced();
    }

    /**
     * 处理 客户端渗透客户端数据传输通道连接成功
     *
     * @return ClientHandleTcpDistributeClientTransferClientPermeateChannelConnectionSuccessfulTypeAdvanced
     */
    @Bean
    public ClientHandleTcpDistributeClientTransferClientPermeateChannelConnectionSuccessfulTypeAdvanced clientHandleDistributeClientTransferClientPermeateChannelConnectionSuccessfulTypeAdvanced() {
        return new ClientHandleTcpDistributeClientTransferClientPermeateChannelConnectionSuccessfulTypeAdvanced();
    }

    @Bean
    public ClientHandleTcpDistributeClientTransferClientPermeateChannelInitSuccessfulTypeAdvanced clientHandleDistributeClientTransferClientPermeateChannelInitSuccessfulTypeAdvanced() {
        return new ClientHandleTcpDistributeClientTransferClientPermeateChannelInitSuccessfulTypeAdvanced();
    }

    @Bean
    public ClientHandleTcpDistributeClientTransferClientRequestTypeAdvanced clientHandleDistributeClientTransferClientTypeAdvanced() {
        return new ClientHandleTcpDistributeClientTransferClientRequestTypeAdvanced();
    }

    @Bean
    public ClientHandleTcpDistributeServicePermeateClientTransferClientResponseTypeAdvanced clientHandleDistributeClientTransferClientResponseTypeAdvanced() {
        return new ClientHandleTcpDistributeServicePermeateClientTransferClientResponseTypeAdvanced();
    }
    @Bean
    public ClientHandleTcpDistributeSingleClientRealCloseVisitorTypeAdvanced handleDistributeSingleClientRealCloseVisitorTypeAdvanced() {
        return new ClientHandleTcpDistributeSingleClientRealCloseVisitorTypeAdvanced();
    }

    @Bean
    public ClientHandleChannelTransferTypeAdvancedHandleDistributeTcpDistribute handleChannelTransferTypeAdvancedHandleDistribute(NettyClientProperties nettyClientProperties) {
        return new ClientHandleChannelTransferTypeAdvancedHandleDistributeTcpDistribute(nettyClientProperties);
    }

    @Bean
    public HandleTcpDistributeConnectSuccessNotificationTypeAdvancedHandle handleDistributeConnectSuccessNotificationTypeAdvancedHandle(ClientChangeEvent clientChangeEvent) {
        return new HandleTcpDistributeConnectSuccessNotificationTypeAdvancedHandle(clientChangeEvent);
    }

    @Bean
    public HandleTcpClientChannelActiveAdvanced handleClientChannelActiveAdvanced(NettyClientProperties nettyClientProperties) {
        return new HandleTcpClientChannelActiveAdvanced(nettyClientProperties);
    }

    @Bean
    public HandleTcpDistributeDisconnectTypeAdvancedHandle handleDistributeDisconnectTypeAdvancedHandle(ClientChangeEvent clientChangeEvent) {
        return new HandleTcpDistributeDisconnectTypeAdvancedHandle(clientChangeEvent);
    }

    @Bean
    public HandleTcpDistributeStagingClosedTypeAdvanced handleDistributeStagingClosedTypeAdvanced() {
        return new HandleTcpDistributeStagingClosedTypeAdvanced();
    }

    @Bean
    public HandleTcpDistributeStagingOpenedTypeAdvanced handleDistributeStagingOpenedTypeAdvanced() {
        return new HandleTcpDistributeStagingOpenedTypeAdvanced();
    }

    /**
     * 处理 客户端渗透服务端init信息
     *
     * @return ClientHandleTcpDistributeClientPermeateServerInitTypeAdvanced
     */
    @Bean
    public ClientHandleTcpDistributeClientPermeateServerInitTypeAdvanced clientHandleDistributeClientPermeateServerInitTypeAdvanced(NettyClientProperties nettyClientProperties) {
        return new ClientHandleTcpDistributeClientPermeateServerInitTypeAdvanced(nettyClientProperties);
    }
    /**
     * 处理 客户端渗透服务端init close 信息
     *
     * @return ClientHandleTcpDistributeClientPermeateServerCloseTypeAdvanced
     */
    @Bean
    public ClientHandleTcpDistributeClientPermeateServerCloseTypeAdvanced clientHandleDistributeClientPermeateServerCloseTypeAdvanced( ) {
        return new ClientHandleTcpDistributeClientPermeateServerCloseTypeAdvanced();
    }
    @Bean
    public ClientHandleTcpDistributeClientPermeateServerTransferTypeAdvanced clientHandleDistributeClientPermeateServerTransferTypeAdvanced( ) {
        return new ClientHandleTcpDistributeClientPermeateServerTransferTypeAdvanced();
    }

    @Bean
    public ClientHandleTcpDistributeClientPermeateClientCloseTypeAdvanced clientHandleDistributeClientPermeateClientCloseTypeAdvanced() {
        return new ClientHandleTcpDistributeClientPermeateClientCloseTypeAdvanced();
    }

    @Bean
    public ClientHandleTcpDistributeClientPermeateClientInitTypeAdvanced clientHandleDistributeClientPermeateClientInitTypeAdvanced() {
        return new ClientHandleTcpDistributeClientPermeateClientInitTypeAdvanced();
    }

    @Bean
    public ClientHandleTcpDistributeClientPermeateClientTransferCloseTypeAdvanced clientHandleDistributeClientPermeateClientTransferCloseTypeAdvanced() {
        return new ClientHandleTcpDistributeClientPermeateClientTransferCloseTypeAdvanced();
    }


    @Bean
    public ClientHandleTcpDistributeServicePermeateClientRealConnectTypeAdvanced clientHandleDistributeSingleClientRealConnectTypeAdvanced(NettyClientProperties nettyClientProperties,
                                                                                                                                           List<HandleChannelTypeAdvanced> handleChannelTypeAdvancedList) {
        return new ClientHandleTcpDistributeServicePermeateClientRealConnectTypeAdvanced(nettyClientProperties, handleChannelTypeAdvancedList);
    }

    @Bean
    public ClientHandleHandleTcpDistributeClientPermeateServerTransferCloseTypeAdvanced clientHandleHandleDistributeClientPermeateServerTransferCloseTypeAdvanced() {
        return new ClientHandleHandleTcpDistributeClientPermeateServerTransferCloseTypeAdvanced();
    }
}
